=== modified file 'olive/commit.py'
--- olive/commit.py	2006-11-02 23:01:58 +0000
+++ olive/commit.py	2006-11-30 13:25:35 +0000
@@ -28,7 +28,7 @@
 import bzrlib.errors as errors
 from bzrlib import osutils
 
-from dialog import error_dialog
+from dialog import error_dialog, question_dialog
 from guifiles import GLADEFILENAME
 
 
@@ -85,12 +85,12 @@
             error_dialog(_('Directory does not have a working tree'),
                          _('Operation aborted.'))
             self.close()
-            return False
+            dialog_shown = False
         if self.notbranch:
             error_dialog(_('Directory is not a branch'),
                          _('You can perform this action only in a branch.'))
             self.close()
-            return False
+            dialog_shown = False
         else:
             if self.wt.branch.get_bound_location() is not None:
                 # we have a checkout, so the local commit checkbox must appear
@@ -105,7 +105,11 @@
             
             self.textview.modify_font(pango.FontDescription("Monospace"))
             self.window.show()
-            return True
+            dialog_shown = True
+        if dialog_shown:
+            # Gives the focus to the commit message area
+            self.textview.grab_focus()
+        return dialog_shown
     
     def _create_file_view(self):
         self.file_store = gtk.ListStore(gobject.TYPE_BOOLEAN,   # [0] checkbox
@@ -259,9 +263,18 @@
             specific_files = self._get_specific_files()
         else:
             specific_files = None
-        
+
+        if message == '':
+            response = question_dialog('Commit with an empty message ?',
+                                       'You can describe your commit intent'
+                                       +' in the message')
+            if response == gtk.RESPONSE_NO:
+                # Kindly give focus to message area
+                self.textview.grab_focus()
+                return
+
         try:
-            self.wt.commit(message, 
+            self.wt.commit(message,
                            allow_pointless=checkbutton_force.get_active(),
                            strict=checkbutton_strict.get_active(),
                            local=self.checkbutton_local.get_active(),

=== modified file 'olive/dialog.py'
--- olive/dialog.py	2006-10-25 16:29:18 +0000
+++ olive/dialog.py	2006-11-30 13:25:35 +0000
@@ -35,10 +35,10 @@
 
     # Set version
     dialog.set_version(olive.__version__)
-    
+
+    dialog.run()
     # Destroy the dialog
-    if dialog.run() == gtk.RESPONSE_CANCEL:
-        dialog.destroy()
+    dialog.destroy()
 
 def _message_dialog(type, primary, secondary):
     """ Display a given type of MessageDialog with the given message.
@@ -62,22 +62,33 @@
                                    type=gtk.MESSAGE_INFO,
                                    buttons=gtk.BUTTONS_OK)
         dialog.set_markup('<big><b>' + primary + '</b></big>')
+    elif type == 'question':
+        dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
+                                   type=gtk.MESSAGE_QUESTION,
+                                   buttons=gtk.BUTTONS_YES_NO)
+        dialog.set_markup('<big><b>' + primary + '</b></big>')
     else:
         return
-    
+
     dialog.format_secondary_markup(secondary)
-    
-    if dialog.run() == gtk.RESPONSE_OK:
-        dialog.destroy()
+
+    response = dialog.run()
+    dialog.destroy()
+
+    return response
 
 def error_dialog(primary, secondary):
     """ Display an error dialog with the given message. """
-    _message_dialog('error', primary, secondary)
+    return _message_dialog('error', primary, secondary)
 
 def info_dialog(primary, secondary):
     """ Display an info dialog with the given message. """
-    _message_dialog('info', primary, secondary)
+    return _message_dialog('info', primary, secondary)
 
 def warning_dialog(primary, secondary):
     """ Display a warning dialog with the given message. """
-    _message_dialog('warning', primary, secondary)
+    return _message_dialog('warning', primary, secondary)
+
+def question_dialog(primary, secondary):
+    """ Display a dialog with the given question. """
+    return _message_dialog('question', primary, secondary)

